.. include:: links.rst

Outputs of Gradec
======================

Gradec includes a wide range of tools with a correspondingly large number of possible outputs.
Here we outline the rules we apply to Gradec outputs.

File names
----------

In Progress!